@@ -1,4 +1,4 @@
-/* $Xorg: objects.c,v 1.3 2000/08/17 19:46:30 cpqbld Exp $ */
+/* $XFree86: xc/lib/font/Type1/objects.c,v 1.13 2006/12/16 15:08:36 tsi Exp $ */
 /* Copyright International Business Machines, Corp. 1991
  * All Rights Reserved
  * Copyright Lexmark International, Inc. 1991
@@ -26,7 +26,6 @@
  * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
  * THIS SOFTWARE.
  */
-/* $XFree86: xc/lib/font/Type1/objects.c,v 1.11 2003/05/27 22:26:45 tsi Exp $ */
  /* OBJECTS  CWEB         V0025 ********                             */
 /*
 :h1.OBJECTS Module - TYPE1IMAGER Objects Common Routines
@@ -60,8 +59,8 @@ you do do not need to include these header files.
 #include  <stdarg.h>
 #include  "os.h"
 #else
-#include "Xdefs.h"	/* Bool declaration */
-#include "Xmd.h"	/* INT32 declaration */
+#include <X11/Xdefs.h>	/* Bool declaration */
+#include <X11/Xmd.h>	/* INT32 declaration */
 #include  "os.h"
 #include "xf86_ansic.h"
 #endif
@@ -299,21 +298,24 @@ t1_Allocate(int size,     /* number of bytes to allocate & initialize     */
 {
        register struct xobject *template = (struct xobject *)ptr;
        register struct xobject *r;
+       int sizer, extrar;
  
        /*
        * round up 'size' and 'extra' to be an integer number of 'long's:
        */
-       size = (size + sizeof(long) - 1) & -(int)sizeof(long);
-       extra = (extra + sizeof(long) - 1) & -(int)sizeof(long);
-       if (size + extra <= 0)
+       sizer = (size + sizeof(long) - 1) & -(int)sizeof(long);
+       extrar = (extra + sizeof(long) - 1) & -(int)sizeof(long);
+       if ((size < 0) || (sizer < size) ||
+           (extra < 0) ||  (extrar < extra) ||
+           (sizer + extrar <= 0))
                Abort("Non-positive allocate?");
-       r = (struct xobject *) xiMalloc(size + extra);
+       r = (struct xobject *) xiMalloc(sizer + extrar);
  
        while (r == NULL) {
                if (!GimeSpace()) {
                        Abort("We have REALLY run out of memory");
                }
-               r = (struct xobject *) xiMalloc(size + extra);
+               r = (struct xobject *) xiMalloc(sizer + extrar);
        }
  
        /*
@@ -325,7 +327,7 @@ t1_Allocate(int size,     /* number of bytes to allocate & initialize     */
           function, which was in turn called by Unique(). (PNM)        */
                if (!ISPERMANENT(template->flag))
                    --template->references;
-               LONGCOPY(r, template, size);
+               LONGCOPY(r, template, sizer);
                r->flag &= ~(ISPERMANENT(ON) | ISIMMORTAL(ON));
        /* added reference field 3-2-6-91 PNM */
                r->references = 1;
@@ -333,7 +335,7 @@ t1_Allocate(int size,     /* number of bytes to allocate & initialize     */
        else {
                register char **p1;
  
-               for (p1=(char **)r; size > 0; size -= sizeof(char *))
+               for (p1=(char **)r; sizer > 0; sizer -= sizeof(char *))
                        *p1++ = NULL;
        }
  
