@@ -1,4 +1,4 @@
-/* $Xorg: PclPrint.c,v 1.3 2000/08/17 19:48:08 cpqbld Exp $ */
+/* $XFree86: xc/programs/Xserver/Xprint/pcl/PclPrint.c,v 1.10 2008/01/01 01:42:00 tsi Exp $ */
 /*******************************************************************
 **
 **    *********************************************************
@@ -43,7 +43,6 @@ not be used in advertising or otherwise to promote the sale, use or other
 dealings in this Software without prior written authorization from said
 copyright holders.
 */
-/* $XFree86: xc/programs/Xserver/Xprint/pcl/PclPrint.c,v 1.8 2003/10/29 22:11:00 tsi Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -54,7 +53,7 @@ copyright holders.
 #include <X11/Xprotostr.h>
 
 #define NEED_EVENTS
-#include "Xproto.h"
+#include <X11/Xproto.h>
 #undef NEED_EVENTS
 
 #include "Pcl.h"
@@ -130,9 +129,6 @@ PclEndJob(
     PclContextPrivPtr priv = (PclContextPrivPtr)
       pCon->devPrivates[PclContextPrivateIndex].ptr;
 
-#ifdef CCP_DEBUG
-    FILE *xpoutput;
-#endif
     FILE *fp;
     int retVal;
     char *fileName, *trailer;
@@ -200,16 +196,6 @@ PclEndJob(
     rewind( priv->pJobFile );
     stat( priv->jobFileName, &statBuf );
     
-#ifdef CCP_DEBUG
-    unlink( "/users/prince/XpOutput" );
-    xpoutput = fopen( "/users/prince/XpOutput", "w" );
-    
-    rewind( priv->pJobFile );
-    TransferBytes( priv->pJobFile, xpoutput,
-		      (int)statBuf.st_size );
-    fclose( xpoutput );
-#endif
-    
     XpSubmitJob( priv->jobFileName, pCon );
     fclose( priv->pJobFile );
     unlink( priv->jobFileName );
