@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/dmx/dmxinit.c,v 1.7 2005/03/07 16:39:17 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/dmx/dmxinit.c,v 1.13 2007/04/03 00:21:12 tsi Exp $ */
 /*
  * Copyright 2001-2004 Red Hat Inc., Durham, North Carolina.
  *
@@ -54,7 +54,7 @@
 #include "dmxpict.h"
 #endif
 
-#include "Xos.h"                /* For gettimeofday */
+#include <X11/Xos.h>                /* For gettimeofday */
 #include "dixstruct.h"
 #include "panoramiXsrv.h"
 
@@ -64,8 +64,8 @@
 #include <GL/glx.h>
 #include <GL/glxint.h>
 #include "dmx_glxvisuals.h"
-#include "Xext.h"
-#include "extutil.h"
+#include <X11/extensions/Xext.h>
+#include <X11/extensions/extutil.h>
 
 extern void GlxSetVisualConfigs(
     int               nconfigs,
@@ -74,9 +74,6 @@ extern void GlxSetVisualConfigs(
 );
 #endif /* GLXPROXY */
 
-extern void SetVendorRelease(int release); /* in dix/main.c */
-extern void SetVendorString(char *string); /* in dix/main.c */
-
 /* Global variables available to all Xserver/hw/dmx routines. */
 int             dmxNumScreens;
 DMXScreenInfo  *dmxScreens;
@@ -522,9 +519,9 @@ static const char *dmxExecOS(void)
 
     if (!initialized++) {
         memset(buffer, 0, sizeof(buffer));
-        uname(&u);
-        XmuSnprintf(buffer, sizeof(buffer)-1, "%s %s %s",
-                    u.sysname, u.release, u.version);
+        if (uname(&u) >= 0)
+	    XmuSnprintf(buffer, sizeof(buffer)-1, "%s %s %s",
+			u.sysname, u.release, u.version);
     }
     return buffer;
 }
@@ -566,7 +563,7 @@ static const char *dmxExecHost(void)
 }
 
 /** This routine is called in Xserver/dix/main.c from \a main(). */
-void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
+void InitOutput(ScreenInfo *pScreenInfo, const int argc, const char *argv[])
 {
     int                  i;
     static unsigned long dmxGeneration = 0;
@@ -819,7 +816,7 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
 /* RATS: Assuming the fp string (which comes from the command-line argv
          vector) is NULL-terminated, the buffer is large enough for the
          strcpy. */ 
-static void dmxSetDefaultFontPath(char *fp)
+static void dmxSetDefaultFontPath(const char *fp)
 {
     int fplen = strlen(fp) + 1;
     
@@ -890,7 +887,7 @@ void ddxInitGlobals(void)
 #endif
 
 /** Process our command line arguments. */
-int ddxProcessArgument(int argc, char *argv[], int i)
+int ddxProcessArgument(int argc, const char *argv[], int i)
 {
     int retval = 0;
     
@@ -1068,7 +1065,7 @@ CARD32 GetTimeInMillis(void)
 
 #ifdef __DARWIN__
 void
-DarwinHandleGUI(int argc, char *argv[])
+DarwinHandleGUI(int argc, const char *argv[], char *envp[])
 {
 }
 #endif
