@@ -58,7 +58,7 @@ THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 **************************************************************************/
 
 
-/* $XFree86: xc/programs/Xserver/hw/tinyx/i810/i810_video.c,v 1.1 2004/06/02 22:43:01 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/tinyx/i810/i810_video.c,v 1.2 2005/10/14 15:16:28 tsi Exp $ */
 /*
  * Copyright (c) 2004 by The XFree86 Project, Inc.
  * All rights reserved.
@@ -120,7 +120,7 @@ THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "txxv.h"
 #include "i810.h"
 
-#include "Xv.h"
+#include <X11/extensions/Xv.h>
 
 #include "../../xfree86/common/fourcc.h"
 
