@@ -1,5 +1,5 @@
 /*
- * $XFree86: xc/programs/Xserver/hw/tinyx/igs/igsdraw.c,v 1.1 2004/06/02 22:43:01 dawes Exp $
+ * $XFree86: xc/programs/Xserver/hw/tinyx/igs/igsdraw.c,v 1.4 2007/09/16 02:10:20 tsi Exp $
  *
  * Copyright  2000 Keith Packard
  *
@@ -71,13 +71,13 @@
 #include "igs.h"
 #include "igsdraw.h"
 
-#include	"Xmd.h"
+#include	<X11/Xmd.h>
 #include	"gcstruct.h"
 #include	"scrnintstr.h"
 #include	"pixmapstr.h"
 #include	"regionstr.h"
 #include	"mistruct.h"
-#include	"fontstruct.h"
+#include	<X11/fonts/fontstruct.h>
 #include	"dixfontstr.h"
 #include	"fb.h"
 #include	"migc.h"
@@ -175,7 +175,7 @@ igsSetPattern (ScreenPtr    pScreen,
 	for (y = 0; y < 8; y++)
 	{
 	    bits = pix[stipY * pixStride];
-	    FbRotLeft (bits, stipX);
+	    bits = FbRotLeft (bits, stipX);
 	    tmp[y] = (CARD8) bits;
 	    stipY++;
 	    if (stipY == pPixmap->drawable.height)
@@ -1348,7 +1348,7 @@ static const GCOps	igsOps = {
 };
 
 static void
-igsValidateGC (GCPtr pGC, Mask changes, DrawablePtr pDrawable)
+igsValidateGC (GCPtr pGC, unsigned long changes, DrawablePtr pDrawable)
 {
     fbValidateGC (pGC, changes, pDrawable);
     
