@@ -1,9 +1,5 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/nsc/nsc_gx1_video.c,v 1.12 2004/04/26 00:23:37 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/nsc/nsc_gx1_video.c,v 1.14 2006/01/09 14:59:55 dawes Exp $ */
 /*
- * $Workfile: nsc_gx1_video.c $
- * $Revision: 11 $
- * $Author: Binesh $
- *
  * File Contents: This file consists of main Xfree video supported routines.
  *
  * Project:       Geode Xfree Frame buffer device driver.
@@ -155,7 +151,7 @@
 #include "regionstr.h"
 
 #include "nsc.h"
-#include "Xv.h"
+#include <X11/extensions/Xv.h>
 #include "xaa.h"
 #include "dixstruct.h"
 #include "fourcc.h"
