@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/include/os.h,v 3.63 2005/02/03 02:01:14 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/include/os.h,v 3.72 2008/05/01 16:13:23 tsi Exp $ */
 /***********************************************************
 
 Copyright 1987, 1998  The Open Group
@@ -47,7 +47,7 @@ SOFTWARE.
 ******************************************************************/
 
 /*
- * Copyright (c) 1996-2005 by The XFree86 Project, Inc.
+ * Copyright (c) 1996-2008 by The XFree86 Project, Inc.
  * All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -99,7 +99,7 @@ SOFTWARE.
 #include "misc.h"
 #define ALLOCATE_LOCAL_FALLBACK(_size) Xalloc((unsigned long)(_size))
 #define DEALLOCATE_LOCAL_FALLBACK(_ptr) Xfree((pointer)(_ptr))
-#include "Xalloca.h"
+#include <X11/Xalloca.h>
 #ifndef IN_MODULE
 #include <stdarg.h>
 #else
@@ -279,13 +279,20 @@ extern void SetDPMSTimers(void);
 extern void FreeDPMSTimers(void);
 #endif
 
-extern SIGVAL AutoResetServer(int /*sig*/);
+#ifdef __GNUC__
+#define NORET __attribute__((noreturn))
+#else
+#define NORET /**/
+#endif
 
+extern SIGVAL AutoResetServer(int /*sig*/);
 extern SIGVAL GiveUp(int /*sig*/);
+extern SIGVAL AbortServer(int /*sig*/) NORET;
+
 
 extern void UseMsg(void);
 
-extern void ProcessCommandLine(int /*argc*/, char* /*argv*/[]);
+extern void ProcessCommandLine(const int /*argc*/, const char* /*argv*/[]);
 
 extern int set_font_authorizations(
     char ** /* authorizations */, 
@@ -336,6 +343,8 @@ extern int OsLookupColor(
 extern void OsInit(void);
 
 extern void OsCleanup(Bool);
+extern void OsPrepareShutdown(Bool);
+extern void OsPrepareRestart(void);
 
 extern void OsVendorFatalError(void);
 
@@ -349,10 +358,10 @@ void OsBlockSignals (void);
 void OsReleaseSignals (void);
 
 #if !defined(WIN32) && !defined(__UNIXOS2__)
-extern int System(char *);
-extern pointer Popen(char *, char *);
+extern int System(const char *);
+extern pointer Popen(const char *, const char *);
 extern int Pclose(pointer);
-extern pointer Fopen(char *, char *);
+extern pointer Fopen(const char *, const char *);
 extern int Fclose(pointer);
 #else
 #define System(a) system(a)
@@ -362,7 +371,7 @@ extern int Fclose(pointer);
 #define Fclose(a) fclose(a)
 #endif
 
-extern void CheckUserParameters(int argc, char **argv, char **envp);
+extern void CheckUserParameters(const int argc, const char **argv, char **envp);
 extern void CheckUserAuthorization(void);
 
 extern int AddHost(
@@ -406,7 +415,7 @@ extern int GetAccessControl(void);
 
 extern void AddLocalHosts(void);
 
-extern void ResetHosts(char *display);
+extern void ResetHosts(const char *display);
 
 extern void EnableLocalHost(void);
 
@@ -418,7 +427,7 @@ extern void DefineSelf(int /*fd*/);
 
 extern void AugmentSelf(pointer /*from*/, int /*len*/);
 
-extern void InitAuthorization(char * /*filename*/);
+extern void InitAuthorization(const char * /*filename*/);
 
 /* extern int LoadAuthorization(void); */
 
@@ -472,7 +481,7 @@ extern XID GenerateAuthorization(
 extern void ExpandCommandLine(int * /*pargc*/, char *** /*pargv*/);
 #endif
 
-extern int ddxProcessArgument(int /*argc*/, char * /*argv*/ [], int /*i*/);
+extern int ddxProcessArgument(int /*argc*/, const char * /*argv*/ [], int /*i*/);
 
 extern void ddxUseMsg(void);
 
@@ -537,7 +546,8 @@ typedef enum _LogParameter {
     XLOG_FLUSH,
     XLOG_SYNC,
     XLOG_VERBOSITY,
-    XLOG_FILE_VERBOSITY
+    XLOG_FILE_VERBOSITY,
+    XLOG_STDERR			/* Redirect stderr to the log */
 } LogParameter;
 
 /* Flags for log messages. */
@@ -586,6 +596,12 @@ __attribute((noreturn))
 #endif
 ;
 
+#ifdef __GNUC__
+#define FatalAlloc()	FatalError("Out of Memory: %s() %s:%d", __FUNCTION__, __FILE__, __LINE__); 
+#else
+#define FatalAlloc()	FatalError("Out of Memory: %s:%d", __FILE__, __LINE__); 
+#endif
+
 extern void VErrorF(const char *f, va_list args);
 extern void ErrorF(const char *f, ...) _printf_attribute(1,2);
 extern void Error(char *str);
@@ -599,8 +615,8 @@ extern int snprintf(char *str, size_t size, const char *format, ...)
 extern int vsnprintf(char *str, size_t size, const char *format, va_list ap);
 #endif
 #if defined(NEED_STRLCAT)
-extern size_t strlcat(char *dst, const char *src, size_t size);
-extern size_t strlcpy(char *dst, const char *src, size_t size);
+#include "strlcat.h"
+#include "strlcpy.h"
 #endif
 #endif
 
@@ -613,4 +629,12 @@ extern int Xasprintf(char **ret, const char *format, ...)
 #define printf xf86printf
 #endif
 
+extern int getArgc(void);
+extern const char **getArgvp(void);
+extern const char *getArgv(int i);
+
+#ifdef __DARWIN__
+extern void DarwinHandleGUI(int argc, const char *argv[], char *envp[]);
+#endif
+
 #endif /* OS_H */
